@@ -82,7 +82,7 @@ class TransactionsManager(Manager):
 
         #status = True for a successful connection
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             transaction = Transaction.from_json(data)
             return transaction
         else:
@@ -108,10 +108,11 @@ class TransactionsManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
+            data_dict = data
             transaction = Transaction.from_json(data)
-            transaction.email = data['customer']['email']
-            transaction.authorization_code = data['authorization']['authorization_code']
+            transaction.email = data_dict['customer']['email']
+            transaction.authorization_code = data_dict['authorization']['authorization_code']
             return transaction
         else:
             raise APIConnectionFailedError(message)
@@ -274,7 +275,8 @@ class CustomersManager(Manager):
             meta = content['meta']
             customers = []
             for item in data:
-                customer = Customer.from_json(item, pickled=False)
+                item = json.JSONEncoder().encode(item)
+                customer = Customer.from_json(item)
                 customers.append(customer)
                 return (customers, meta)
 
@@ -300,8 +302,8 @@ class CustomersManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = content['data']
-            customer = Customer.from_json(data, pickled='False')
+            data = json.JSONEncoder().encode(content['data'])
+            customer = Customer.from_json(data)
             return customer
         else:
             raise APIConnectionFailedError(message)
@@ -328,7 +330,7 @@ class CustomersManager(Manager):
 
         status, message = self.get_content_status(content)
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             return Customer.from_json(data)
         else:
             raise APIConnectionFailedError(message)
@@ -364,7 +366,7 @@ class CustomersManager(Manager):
             status, message = self.get_content_status(content)
 
             if status:
-                data = content['data']
+                data = json.JSONEncoder().encode(content['data'])
                 return Customer.from_json(data)
             else:
                 raise APIConnectionFailedError(message)
@@ -428,7 +430,7 @@ class PlanManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             return Plan.from_json(data)
         else:
             raise APIConnectionFailedError(message)
@@ -450,6 +452,7 @@ class PlanManager(Manager):
             meta = content['meta']
             plans = []
             for item in data:
+                item = json.JSONEncoder().encode(item)
                 plan = Plan.from_json(item)
                 plans.append(plan)
                 return (plans, meta)
@@ -471,7 +474,7 @@ class PlanManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             plan = Plan.from_json(data)
             return plan
         else:
@@ -494,7 +497,7 @@ class PlanManager(Manager):
 
         status, message = self.get_content_status(content)
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             return Plan.from_json(data)
         else:
             raise APIConnectionFailedError(message)
@@ -531,7 +534,7 @@ class TransfersManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             transfer = Transfer.from_json(data)
             return transfer
 
@@ -557,6 +560,7 @@ class TransfersManager(Manager):
             data = content['data']
             transfers = []
             for item in data:
+                item = json.JSONEncoder().encode(item)
                 transfers.append(Transfer.from_json(item))
 
             return transfers
@@ -580,7 +584,7 @@ class TransfersManager(Manager):
         status, message = self.get_content_status(content)
 
         if status:
-            data = content['data']
+            data = json.JSONEncoder().encode(content['data'])
             return Transfer.from_json(data)
         else:
             #Connection failed
